.. PTMCMCSampler documentation master file, created by
   sphinx-quickstart on Sat Mar 28 20:40:33 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PTMCMCSampler's documentation!
=========================================

Contents:

.. toctree::
   :maxdepth: 4

   PTMCMCSampler


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

